F-1.LT

Vartotojo vardas: Slaptažodis: Prisiminti Registracija Naujienos el. paštu Priminti slaptažodį 2014 m. galutinė įskaita:
1 | L. Hamiltonas | 384
2 | N. Rosbergas | 317
3 | D. Ricciardo | 238
4 | V. Bottas | 186
5 | S. Vettelis | 167
6 | F. Alonso | 161
7 | F. Massa | 134
8 | J. Buttonas | 126
9 | N. Hulkenbergas | 96
10 | S. Perezas | 59
11 | K. Magnussenas | 55
12 | K. Raikkonenas | 55
13 | J.-E. Vergne | 22
14 | R. Grosjeanas | 8
15 | D. Kvyatas | 8
16 | P. Maldonado | 2
17 | J. Bianchi | 2
18 | A. Sutilas | 0
19 | M. Ericssonas | 0
20 | E. Gutierrezas | 0
21 | M. Chiltonas | 0
22 | K. Kobayashi | 0
23 | W. Stevensas | 0
24 | A. Lottereris | 0
2014 m. galutinė įskaita:
1 | Mercedes | 701
2 | Red Bull | 405
3 | Williams | 320
4 | Ferrari | 216
5 | McLaren | 181
6 | Force India | 155
7 | Toro Rosso | 30
8 | Lotus | 10
9 | Marussia | 2
10 | Sauber | 0
11 | Caterham | 0
Iki 2015 m. Australijos GP liko 95 d. 13 h 13 min. | 2014 m. gruodžio 9 d., 18:46
Tapdami F-1.LT vartotoju, Jūs sutinkate, kad šis, registruojamas vartotojo vardas yra vienintelis Jūsų naudojamas F-1.LT vartotojo vardas ir Jūs sutinkate su žemiau pateiktomis taisyklėmis. Kiekvienas F-1.LT vartotojas, po registracijos praėjus 2 savaitėms, turi teisę komentuoti naujienas, dalyvauti diskusijuose ir svetainės žaidimuose bei konkursuose. Kiekvienas vartotojas yra atsakingas už teisingų duomenų apie save pateikimą. Diskutuojančiam ar reiškiančiam savo nuomonę vartotojui siūloma argumentuoti ir aiškiai kitiems vartotojams reikšti savo poziciją bei vengti bereikšmių užuominų, įžeidimų, provokacijų ar informacijos, nesusijusios su aptariama tema. Vartotojai, turintys klausimų, pasiūlymų, arba norintys kreiptis į svetainės administratorius, turi juos skelbti atskirame F-1.LT forume arba rašyti šiuo info@f-1.lt adresu. Draudžiami veiksmai: Nenormatyvinės leksikos (keiksmų, įžedžiančio slengo ir t.t.) naudojimas. Kitų vartotojų ar trečiųjų asmenų įžeidimai ir nepagarbos jiems reiškimas. Teksto ar temos pavadinimo rašymas didžiosiomis raidėmis. Taip pat dažnas didžiųjų raidžių naudojimas. Kitų interneto svetainių reklama be išankstinio leidimo, įskaitant lietuviškų F-1 portalų adresų skelbimą. Žinučių ar komentarų, nesusijusių su naujienos ar diskusijos tema skelbimas. Žinučių ar komentarų, kuriuose siekiama populiarumo, reklamos ir t.t. skelbimas. Kitų vartotojų provokavimas ir/arba priešinimas tarpusavyje. Lenktynių rezultatų, "LIVE" transliacijų skelbimas ir aptarimas tam neskirtose vietose. Perdėtas "veidukų" naudojimas diskusijuose. Tos pačios žinutės ar komentaro skelbimas įvairiuose diskusijose ar naujienose. Dvejų ir daugiau žinučių ar komentarų skelbimas iš eilės, jei yra galimybė viską skelbti vienoje žinutėje ar komentare. Paskirtų nuobaudų diskutavimas. Veiksmai, kenkiantys F-1.LT vartotojų bendruomenei apskritai. Kita veikla, kenkianti F-1.LT portalo ir/arba jo prižiūrėtojų interesams. Vartotojai, pažeidę šias taisykles gali būti įspėti, laikinai ar visam laikui nušalinti nuo naujienų komentavimo bei dalyvavimo diskusijose. Paskyrus nuobaudą, vartotojas yra automatiškai apie tai informuojamas registracijos metu nurodytu el. pašto adresu. Kai vartotojas yra įspėjamas ar pašalinamas, šalia jo vartotojo vardo atsiranda geltonos ar raudona kortelės, o prie jo komentaro atsiranda užrašas "Vartotojas už šio komentaro turinį buvo įspėtas" arba "Vartotojas už šio komentaro turinį buvo pašalintas". Viena geltona kortelė - vienas įspėjimas, dvi geltonos kortelės - du įspejimai, dvi geltonos ir viena raudona kortelė - pašalinimas. Vienos kortelės galiojimas - 2 savaitės (14 dienų). Taigi po 2 savaičių, anksčiau pašalintas vartotojas ir vėl galės diskutuoti ir komentuoti naujienas. Atskirais atvejais svetainės administratoriai palieka sau teisę pašalinti vartotoją be įspėjimų (antras vieno asmens vartotojo vardas, šiurkštus ir/ar pakartotinas taisyklių pažeidimas ir t.t.). Taisyklių neatitinkanti diskusija ar komentaras dažniausiai yra ištrinami. Užpildykite registracijos anketą. Tai padarę, el. paštu gausite nuorodą į tinklalapį, kurio pagalba galėsite aktyvuoti savo vartotojo vardą. Prašome įvesti tik teisingus duomenis!
Vartotojo vardas: |
Slaptažodis: |
El. pašto adresas: |
F-1.LT suteikia jums galimybę užsisakyti svetainės naujienas į savo el. pašto dėžutę.
| Nenoriu gauti F-1.LT naujienų el. paštu Pažymėkite šį pasirinkimą, jei nenorite, kad F-1.LT jums el. paštu siųstų naujienas.
| Iš karto po įdėjimo Pažymėkite šį pasirinkimą, jei norite gauti F-1.LT naujienas beveik iš karto po jų įdėjimo į svetainę. Norite pamatyti, kaip atrodys laiškas, atsiųstas jums? Spauskite čia!
| Vieną kartą per dieną Pažymėkite šį pasirinkimą, jei norite gauti F-1.LT naujienų santrauką vieną kartą per dieną - kiekvieną rytą, 9 val. Norite pamatyti, kaip atrodys laiškas, atsiųstas jums? Spauskite čia!

Kaip vertinate 2014 m. sezoną?

Teigiamai | 60%
Neigiamai | 35%
Neturiu nuomonės | 4%
Viso balsų | 282

El. pašto adresas:
@f-1.lt
Slaptažodis:
Dar neturi el. pašto
@f-1.lt?
Registruokis!

© 1996-2012 F-1.LT Rašykite el. paštu info@f-1.lt Privatumo politika |
KATINODIENOS.LT Apgyvendinimas Lietuvoje |  | Naujienos online |  | eracing.lt LFS/rF naujienos |  | EINAM.LT Renginių anonsas |  | KAINOS.LT Kainų palyginimas |  | SEFORECEPTAI.LT Skaniausi receptai